# Example at the end of Section 5.2 of Latouche et al. (2004)
# for a cohort study.
D <- numDEpi.default(power = 0.8, theta = 2, p = 0.39,
rho2 = 0.132^2, alpha = 0.05)
# proportion of subjects died of the disease of interest.
psi <- 0.505
# total number of subjects required to achieve the desired power
ceiling(D / psi)Run the code above in your browser using DataLab