powerCT.default: Power Calculation in the Analysis of Survival Data for Clinical Trials
Description
Power calculation for the Comparison of Survival Curves Between Two Groups under
the Cox Proportional-Hazards Model for clinical trials.
Usage
powerCT.default(nE, nC, pE, pC, RR, alpha = 0.05)
Arguments
nE
number of participants in the experimental group.
nC
number of participants in the control group.
pE
probability of failure in group E (experimental group) over the maximum time period of the study (t years).
pC
probability of failure in group C (control group) over the maximum time period of the study (t years).
RR
postulated hazard ratio.
alpha
type I error rate.
Value
The power of the test.
Details
This is an implementation of the power calculation method described in Section 14.12 (page 807)
of Rosner (2006). The method was proposed by Freedman (1982).
Suppose we want to compare the survival curves between an experimental group ($E$) and
a control group ($C$) in a clinical trial with a maximum follow-up of $t$ years.
The Cox proportional hazards regression model is assumed to have the form:
$$h(t|X_1)=h_0(t)\exp(\beta_1 X_1).$$
Let $n_E$ be the number of participants in the $E$ group
and $n_C$ be the number of participants in the $C$ group.
We wish to test the hypothesis $H0: RR=1$ versus $H1: RR$ not equal to 1,
where $RR=\exp(\beta_1)=$underlying hazard ratio
for the $E$ group versus the $C$ group. Let $RR$ be the postulated hazard ratio,
$\alpha$ be the significance level. Assume that the test is a two-sided test.
If the ratio of participants in group
E compared to group C $= n_E/n_C=k$, then the power of the test is
$$power=\Phi(\sqrt{k*m}*|RR-1|/(k*RR+1)-z_{1-\alpha/2}),$$
where $$m=n_E p_E+n_C p_C,$$
and $z_{1-\alpha/2}$
is the $100 (1-\alpha/2)$ percentile of
the standard normal distribution $N(0, 1)$, $\Phi$ is the cumulative distribution function (CDF)
of $N(0, 1)$.
References
Freedman, L.S. (1982).
Tables of the number of patients required in clinical trials using the log-rank test.
Statistics in Medicine. 1: 121-129
Rosner B. (2006).
Fundamentals of Biostatistics. (6-th edition). Thomson Brooks/Cole.