Learn R Programming

powerSurvEpi (version 0.0.6)

powerEpiInt: Power Calculation Testing Interaction Effect for Cox Proportional Hazards Regression with two covariates for Epidemiological Studies (Both covariates should be binary)

Description

Power calculation testing interaction effect for Cox proportional hazards regression with two covariates for Epidemiological Studies. Both covariates should be binary variables. The formula takes into account the correlation between the two covariates. Some parameters will be estimated based on a pilot study.

Usage

powerEpiInt(X1, X2, failureFlag, n, theta, alpha = 0.05)

Arguments

X1
a nPilot by 1 vector, where nPilot is the number of subjects in the pilot data set. This vector records the values of the covariate of interest for the nPilot subjects in the pilot study. X1 sh
X2
a nPilot by 1 vector, where nPilot is the number of subjects in the pilot study. This vector records the values of the second covariate for the nPilot subjects in the pilot study. X2 should
failureFlag
a nPilot by 1 vector of indicators indicating if a subject is failure (failureFlag=1) or alive (failureFlag=0).
n
total number of subjects.
theta
postulated hazard ratio.
alpha
type I error rate.

Value

  • powerthe power of the test.
  • pestimated $Pr(X_1=1)$
  • qestimated $Pr(X_2=1)$
  • p0estimated $Pr(X_1=1 | X_2=0)$
  • p1estimated $Pr(X_1=1 | X_2=1)$
  • rho2square of the estimated $corr(X_1, X_2)$
  • Ga factor adjusting the sample size. The sample size needed to detect an effect of a prognostic factor with given error probabilities has to be multiplied by the factor G when an interaction of the same magnitude is to be detected.
  • myaestimated number of subjects taking values $X_1=0$ and $X_2=0$.
  • mybestimated number of subjects taking values $X_1=0$ and $X_2=1$.
  • mycestimated number of subjects taking values $X_1=1$ and $X_2=0$.
  • mydestimated number of subjects taking values $X_1=1$ and $X_2=1$.
  • psiproportion of subjects died of the disease of interest.

Details

This is an implementation of the power calculation formula derived by Schmoor et al. (2000) for the following Cox proportional hazards regression in the epidemoilogical studies: $$h(t|x_1, x_2)=h_0(t)\exp(\beta_1 x_1+\beta_2 x_2 + \gamma (x_1 x_2)),$$ where both covariates $X_1$ and $X_2$ are binary variables.

Suppose we want to check if the hazard ratio of the interaction effect $X_1 X_2=1$ to $X_1 X_2=0$ is equal to $1$ or is equal to $\exp(\gamma)=\theta$. Given the type I error rate $\alpha$ for a two-sided test, the power required to detect a hazard ratio as small as $\exp(\gamma)=\theta$ is: $$power=\Phi\left(-z_{1-\alpha/2}+\sqrt{\frac{n}{\delta}[\log(\theta)]^2 \psi}\right),$$ where $$\delta=\frac{1}{p_{00}}+\frac{1}{p_{01}}+\frac{1}{p_{10}} +\frac{1}{p_{11}},$$ $\psi$ is the proportion of subjects died of the disease of interest, and $p_{00}=Pr(X_1=0,\mbox{and}, X_2=0)$, $p_{01}=Pr(X_1=0,\mbox{and}, X_2=1)$, $p_{10}=Pr(X_1=1,\mbox{and}, X_2=0)$, $p_{11}=Pr(X_1=1,\mbox{and}, X_2=1)$.

$p_{00}$, $p_{01}$, $p_{10}$, $p_{11}$, and $\psi$ will be estimated from the pilot data.

References

Schmoor C., Sauerbrei W., and Schumacher M. (2000). Sample size considerations for the evaluation of prognostic factors in survival analysis. Statistics in Medicine. 19:441-452.

See Also

powerEpiInt.default0, powerEpiInt2

Examples

Run this code
# generate a toy pilot data set
  X1 <- c(rep(1, 39), rep(0, 61))
  set.seed(123456)
  X2 <- sample(c(0, 1), 100, replace = TRUE)
  failureFlag <- sample(c(0, 1), 100, prob = c(0.25, 0.75), replace = TRUE)

  powerEpiInt(X1, X2, failureFlag, n = 184, theta = 3, alpha = 0.05)

Run the code above in your browser using DataLab