Learn R Programming

powerSurvEpi (version 0.0.9)

powerEpiInt2: Power Calculation Testing Interaction Effect for Cox Proportional Hazards Regression

Description

Power calculation testing interaction effect for Cox proportional hazards regression with two covariates for Epidemiological Studies. Both covariates should be binary variables. The formula takes into account the correlation between the two covariates.

Usage

powerEpiInt2(n, theta, psi, mya, myb, myc, myd, alpha = 0.05)

Arguments

n
total number of subjects.
theta
postulated hazard ratio.
psi
proportion of subjects died of the disease of interest.
mya
number of subjects taking values $X_1=0$ and $X_2=0$ obtained from a pilot study.
myb
number of subjects taking values $X_1=0$ and $X_2=1$ obtained from a pilot study.
myc
number of subjects taking values $X_1=1$ and $X_2=0$ obtained from a pilot study.
myd
proportion of subjects taking values $X_1=1$ and $X_2=1$ obtained from a pilot study.
alpha
type I error rate.

Value

  • The power of the test.

Details

This is an implementation of the power calculation formula derived by Schmoor et al. (2000) for the following Cox proportional hazards regression in the epidemiological studies: $$h(t|x_1, x_2)=h_0(t)\exp(\beta_1 x_1+\beta_2 x_2 + \gamma (x_1 x_2)),$$ where both covariates $X_1$ and $X_2$ are binary variables.

Suppose we want to check if the hazard ratio of the interaction effect $X_1 X_2=1$ to $X_1 X_2=0$ is equal to $1$ or is equal to $\exp(\gamma)=\theta$. Given the type I error rate $\alpha$ for a two-sided test, the power required to detect a hazard ratio as small as $\exp(\gamma)=\theta$ is $$power=\Phi\left(-z_{1-\alpha/2}+\sqrt{\frac{n}{G}[\log(\theta)]^2 p (1-p) \psi (1-\rho^2)}\right),$$ where $\psi$ is the proportion of subjects died of the disease of interest, and $$\rho=corr(X_1, X_2)=(p_1-p_0)\times\sqrt{\frac{q(1-q)}{p(1-p)}},$$ and $p=Pr(X_1=1)$, $q=Pr(X_2=1)$, $p_0=Pr(X_1=1|X_2=0)$, and $p_1=Pr(X_1=1 | X_2=1)$, and $$G=\frac{[(1-q)(1-p_0)p_0+q(1-p_1)p_1]^2}{(1-q)q (1-p_0)p_0 (1-p_1) p_1},$$ and $p0=Pr(X_1=1 | X_2=0)=myc/(mya+myc)$, $p1=Pr(X_1=1 | X_2=1)=myd/(myb+myd)$, $p=Pr(X_1=1)=(myc+myd)/n_{obs}$, $q=Pr(X_2=1)=(myb+myd)/n_{obs}$, $n_{obs}=mya+myb+myc+myd$.

$p_{00}=Pr(X_1=0,\mbox{and}, X_2=0)$, $p_{01}=Pr(X_1=0,\mbox{and}, X_2=1)$, $p_{10}=Pr(X_1=1,\mbox{and}, X_2=0)$, $p_{11}=Pr(X_1=1,\mbox{and}, X_2=1)$.

References

Schmoor C., Sauerbrei W., and Schumacher M. (2000). Sample size considerations for the evaluation of prognostic factors in survival analysis. Statistics in Medicine. 19:441-452.

See Also

powerEpiInt.default0, powerEpiInt.default1

Examples

Run this code
# Example at the end of Section 4 of Schmoor et al. (2000).
  # mya, myb, myc, and myd are obtained from Table III on page 448
  # of Schmoor et al. (2000).
  powerEpiInt2(n = 184, theta = 3, psi = 139 / 184,
    mya = 50, myb = 21, myc = 78, myd = 35, alpha = 0.05)

Run the code above in your browser using DataLab