Learn R Programming

powerSurvEpi (version 0.0.9)

ssizeEpiCont.default: Sample Size Calculation for Cox Proportional Hazards Regression with Nonbinary Covariates for Epidemiological Studies

Description

Sample size calculation for Cox proportional hazards regression with nonbinary covariates for Epidemiological Studies.

Usage

ssizeEpiCont.default(power, theta, sigma2, psi, rho2, alpha = 0.05)

Arguments

power
postulated power.
theta
postulated hazard ratio.
sigma2
variance of the covariate of interest.
psi
proportion of subjects died of the disease of interest.
rho2
square of the multiple correlation coefficient between the covariate of interest and other covariates.
alpha
type I error rate.

Value

  • The total number of subjects required.

Details

This is an implementation of the sample size calculation formula derived by Hsieh and Lavori (2000) for the following Cox proportional hazards regression in the epidemiological studies: $$h(t|x_1, \boldsymbol{x}_2)=h_0(t)\exp(\beta_1 x_1+\boldsymbol{\beta}_2 \boldsymbol{x}_2,$$ where the covariate $X_1$ is a nonbinary variable and $\boldsymbol{X}_2$ is a vector of other covariates. Suppose we want to check if the hazard ratio of the main effect $X_1=1$ to $X_1=0$ is equal to $1$ or is equal to $\exp(\beta_1)=\theta$. Given the type I error rate $\alpha$ for a two-sided test, the total number of subjects required to achieve a sample size of $1-\beta$ is $$n=\frac{\left(z_{1-\alpha/2}+z_{1-\beta}\right)^2}{ [\log(\theta)]^2 \sigma^2 \psi (1-\rho^2) },$$ where $\sigma^2=Var(X_1)$, $\psi$ is the proportion of subjects died of the disease of interest, and $\rho$ is the multiple correlation coefficient of the following linear regression: $$x_1=b_0+\boldsymbol{b}^T\boldsymbol{x}_2.$$ That is, $\rho^2=R^2$, where $R^2$ is the proportion of variance explained by the regression of $X_1$ on the vector of covriates $\boldsymbol{X}_2$.

References

Hsieh F.Y. and Lavori P.W. (2000). Sample-size calculation for the Cox proportional hazards regression model with nonbinary covariates. Controlled Clinical Trials. 21:552-560.

See Also

ssizeEpiCont

Examples

Run this code
# example in the EXAMPLE section (page 557) of Hsieh and Lavori (2000).
  # Hsieh and Lavori (2000) assumed one-sided test, 
  # while this implementation assumed two-sided test. 
  # Hence alpha=0.1 here (two-sided test) will correspond
  # to alpha=0.05 of one-sided test in Hsieh and Lavori's (2000) example.
  ssizeEpiCont.default(power = 0.806, theta = exp(1), sigma2 = 0.3126^2, 
    psi = 0.738, rho2 = 0.1837, alpha = 0.1)

Run the code above in your browser using DataLab