Learn R Programming

powerSurvEpi (version 0.0.9)

ssizeEpiInt.default1: Sample Size Calculation Testing Interaction Effect for Cox Proportional Hazards Regression

Description

Sample size calculation testing interaction effect for Cox proportional hazards regression with two covariates for Epidemiological Studies. Both covariates should be binary variables. The formula takes into account the correlation between the two covariates.

Usage

ssizeEpiInt.default1(power, theta, psi, p00, p01, p10, p11, alpha = 0.05)

Arguments

power
postulated power.
theta
postulated hazard ratio.
psi
proportion of subjects died of the disease of interest.
p00
proportion of subjects taking values $X_1=0$ and $X_2=0$, i.e., $p_{00}=Pr(X_1=0,\mbox{and}, X_2=0)$.
p01
proportion of subjects taking values $X_1=0$ and $X_2=1$, i.e., $p_{01}=Pr(X_1=0,\mbox{and}, X_2=1)$.
p10
proportion of subjects taking values $X_1=1$ and $X_2=0$, i.e., $p_{10}=Pr(X_1=1,\mbox{and}, X_2=0)$.
p11
proportion of subjects taking values $X_1=1$ and $X_2=1$, i.e., $p_{11}=Pr(X_1=1,\mbox{and}, X_2=1)$.
alpha
type I error rate.

Value

  • The ssize of the test.

Details

This is an implementation of the sample size calculation formula derived by Schmoor et al. (2000) for the following Cox proportional hazards regression in the epidemoilogical studies: $$h(t|x_1, x_2)=h_0(t)\exp(\beta_1 x_1+\beta_2 x_2 + \gamma (x_1 x_2)),$$ where both covariates $X_1$ and $X_2$ are binary variables.

Suppose we want to check if the hazard ratio of the interaction effect $X_1 X_2=1$ to $X_1 X_2=0$ is equal to $1$ or is equal to $\exp(\gamma)=\theta$. Given the type I error rate $\alpha$ for a two-sided test, the total number of subjects required to achieve a power of $1-\beta$ is $$n=\frac{\left(z_{1-\alpha/2}+z_{1-\beta}\right)^2\delta}{[\log(\theta)]^2 \psi},$$ where $\psi$ is the proportion of subjects died of the disease of interest, $$\delta=\frac{1}{p_{00}}+\frac{1}{p_{01}}+\frac{1}{p_{10}} +\frac{1}{p_{11}},$$ and $p_{00}=Pr(X_1=0,\mbox{and}, X_2=0)$, $p_{01}=Pr(X_1=0,\mbox{and}, X_2=1)$, $p_{10}=Pr(X_1=1,\mbox{and}, X_2=0)$, $p_{11}=Pr(X_1=1,\mbox{and}, X_2=1)$.

References

Schmoor C., Sauerbrei W., and Schumacher M. (2000). Sample size considerations for the evaluation of prognostic factors in survival analysis. Statistics in Medicine. 19:441-452.

See Also

ssizeEpiInt.default0, ssizeEpiInt2

Examples

Run this code
# Example at the end of Section 4 of Schmoor et al. (2000).
  # p00, p01, p10, and p11 are calculated based on Table III on page 448
  # of Schmoor et al. (2000).
  ssizeEpiInt.default1(power = 0.8227, theta = 3, psi = 139 / 184,
    p00 = 50/184, p01 = 21 / 184, p10 = 78 / 184, p11 = 35 / 184,
    alpha = 0.05)

Run the code above in your browser using DataLab